@@ -655,14 +655,11 @@ void WidgetBasePopupMenu::insertSubMenuNew(WidgetBase::WidgetType type, KMenu *m
         case WidgetBase::wt_Enum:
             insert(mt_EnumLiteral, menu);
             break;
-        case WidgetBase::wt_Activity:
-            insert(mt_New_Activity, menu);
-            break;
         default:
             break;
     }
-    insert(mt_FloatText, menu);
     insert(mt_Note, menu);
+    insert(mt_FloatText, menu);
 
     addMenu(menu);
 }
